==> hinemos_src-4.0.3.tar.gz: HinemosManager/src_winservice/com/clustercontrol/winservice/factory/SelectMonitorWinService.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.winservice.factory;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import com.clustercontrol.monitor.run.factory.SelectMonitor;
import com.clustercontrol.winservice.bean.WinServiceCheckInfo;
import com.clustercontrol.winservice.ejb.entity.MonitorWinServiceInfoLocal;
import com.clustercontrol.winservice.ejb.entity.MonitorWinServiceInfoUtil;

/**
 * Windowsサービス監視判定情報を検索するクラス<BR>
 *
 * @version 4.0.0
 * @since 4.0.0
 */
public class SelectMonitorWinService extends SelectMonitor{

	/* (非 Javadoc)
	 * @see com.clustercontrol.monitor.run.factory.SelectMonitor#getCheckInfo()
	 */
	@Override
	protected WinServiceCheckInfo getWinServiceCheckInfo() throws FinderException, NamingException{

		// プロセス監視情報を取得
		MonitorWinServiceInfoLocal winServicelocal = MonitorWinServiceInfoUtil.getLocalHome().findByPrimaryKey(m_monitorId);

		WinServiceCheckInfo winService = new WinServiceCheckInfo();
		winService.setMonitorTypeId(m_monitorTypeId);
		winService.setMonitorId(m_monitorId);
		winService.setServiceName(winServicelocal.getServiceName());

		return winService;
	}
}

==> hinemos_src-4.1.1.tar.gz: HinemosManager/src_winservice/com/clustercontrol/winservice/factory/SelectMonitorWinService.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.winservice.factory;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.fault.MonitorNotFound;
import com.clustercontrol.monitor.run.factory.SelectMonitor;
import com.clustercontrol.winservice.bean.WinServiceCheckInfo;
import com.clustercontrol.winservice.model.MonitorWinserviceInfoEntity;
import com.clustercontrol.winservice.util.QueryUtil;

/**
 * Windowsサービス監視判定情報を検索するクラス<BR>
 *
 * @version 4.0.0
 * @since 4.0.0
 */
public class SelectMonitorWinService extends SelectMonitor{

	private static Log m_log = LogFactory.getLog(SelectMonitorWinService.class);

	/* (非 Javadoc)
	 * @see com.clustercontrol.monitor.run.factory.SelectMonitor#getCheckInfo()
	 */
	@Override
	protected WinServiceCheckInfo getWinServiceCheckInfo() throws MonitorNotFound {

		// Windowsサービス監視情報を取得
		MonitorWinserviceInfoEntity entity = QueryUtil.getMonitorWinserviceInfoPK(m_monitorId);

		WinServiceCheckInfo winService = new WinServiceCheckInfo();
		winService.setMonitorTypeId(m_monitorTypeId);
		winService.setMonitorId(m_monitorId);
		winService.setServiceName(entity.getServiceName());

		return winService;
	}
}
